@@ -9,7 +9,7 @@ import tempfile
 from importlib import import_module
 from pathlib import Path
 from textwrap import dedent
-from typing import Dict, Iterator, List, Optional, Set, Tuple
+from typing import Iterator, Mapping, MutableMapping, Optional, Sequence, Set, Tuple
 
 from pkg_resources import parse_version
 
@@ -113,7 +113,7 @@ def _filter_by_include_exclude(
 
 
 def _get_all_notebooks(
-    root_dirs: List[str], files: Optional[str], exclude: Optional[str]
+    root_dirs: Sequence[str], files: Optional[str], exclude: Optional[str]
 ) -> Iterator[Path]:
     """
     Get generator with all notebooks passed in via the command-line, applying exclusions.
@@ -222,6 +222,9 @@ def _replace_temp_python_file_references_in_out_err(
         out = out.replace(path, notebook_path)
         err = err.replace(path, notebook_path)
 
+    out = out.replace(f"{tmpdirname}{os.sep}", "")
+    err = err.replace(f"{tmpdirname}{os.sep}", "")
+
     return out, err
 
 
@@ -243,17 +246,13 @@ def _create_blank_init_files(
     parts = notebook.resolve().relative_to(project_root).parts
 
     for idx in range(1, len(parts)):
-        init_files = Path(os.path.join(*parts[:idx])).glob("__init__.py")
-        for init_file in init_files:
-            Path(tmpdirname).joinpath(init_file).parent.mkdir(
-                parents=True, exist_ok=True
-            )
-            Path(tmpdirname).joinpath(init_file).touch()
-            break  # Only need to copy one __init__ file.
+        init_file = Path(os.path.join(*parts[:idx])) / "__init__.py"
+        Path(tmpdirname).joinpath(init_file).parent.mkdir(parents=True, exist_ok=True)
+        Path(tmpdirname).joinpath(init_file).touch()
 
 
 def _preserve_config_files(
-    config_files: List[str], tmpdirname: str, project_root: Path
+    config_files: Sequence[str], tmpdirname: str, project_root: Path
 ) -> None:
     """
     Copy local config file to temporary directory.
@@ -283,7 +282,7 @@ def _preserve_config_files(
 def _get_arg(
     root_dir: str,
     tmpdirname: str,
-    nb_to_py_mapping: Dict[Path, Path],
+    nb_to_py_mapping: Mapping[Path, Path],
     project_root: Path,
 ) -> Path:
     """
@@ -326,11 +325,11 @@ def _get_arg(
 
 
 def _get_all_args(
-    root_dirs: List[str],
+    root_dirs: Sequence[str],
     tmpdirname: str,
-    nb_to_py_mapping: Dict[Path, Path],
+    nb_to_py_mapping: Mapping[Path, Path],
     project_root: Path,
-) -> List[Path]:
+) -> Sequence[Path]:
     """
     Get all arguments to run command against.
 
@@ -347,7 +346,7 @@ def _get_all_args(
 
     Returns
     -------
-    List[Path]
+    Sequence[Path]
         All notebooks or directories to run third-party tool against.
     """
     return [_get_arg(i, tmpdirname, nb_to_py_mapping, project_root) for i in root_dirs]
@@ -375,8 +374,8 @@ def _get_mtimes(arg: Path) -> Set[float]:
 def _run_command(
     command: str,
     tmpdirname: str,
-    cmd_args: List[str],
-    args: List[Path],
+    cmd_args: Sequence[str],
+    args: Sequence[Path],
 ) -> Tuple[str, str, int, bool]:
     """
     Run third-party tool against given file or directory.
@@ -409,6 +408,10 @@ def _run_command(
         If third-party tool isn't found in system.
     """
     env = os.environ.copy()
+    env[
+        "MYPYPATH"
+    ] = f"{env.get('MYPYPATH', '').rstrip(os.pathsep)}{os.pathsep}{os.getcwd()}"
+
     env[
         "PYTHONPATH"
     ] = f"{env.get('PYTHONPATH', '').rstrip(os.pathsep)}{os.pathsep}{os.getcwd()}"
@@ -543,7 +546,7 @@ def _run_on_one_root_dir(
         )
         _preserve_config_files(config_files, tmpdirname, project_root)
 
-        nb_info_mapping: Dict[Path, NotebookInfo] = {}
+        nb_info_mapping: MutableMapping[Path, NotebookInfo] = {}
 
         for notebook, temp_python_file in nb_to_py_mapping.items():
             try:
@@ -663,7 +666,7 @@ def _check_command_is_installed(command: str) -> None:
                 )
 
 
-def main(argv: Optional[List[str]] = None) -> None:
+def main(argv: Optional[Sequence[str]] = None) -> None:
     """
     Run third-party tool (e.g. :code:`mypy`) against notebook or directory.
 
