@@ -9,7 +9,7 @@ from abc import ABC
 from ast import AST
 from enum import Enum
 from textwrap import dedent, indent
-from typing import ClassVar, Dict, List, Optional, Pattern
+from typing import ClassVar, Mapping, Optional, Pattern, Sequence
 
 with warnings.catch_warnings():
     # see https://github.com/nbQA-dev/nbQA/issues/459
@@ -48,7 +48,7 @@ class MagicHandler(ABC):
     # To Developers: Its better to preserve the order in which
     # this dictionary is populated. For instance, if HELP is inserted
     # after LINE leads to bug, since they both share the same prefix.
-    _MAGIC_PREFIXES: ClassVar[Dict[IPythonMagicType, List[str]]] = {
+    _MAGIC_PREFIXES: ClassVar[Mapping[IPythonMagicType, Sequence[str]]] = {
         IPythonMagicType.SHELL: ["get_ipython().system", "get_ipython().getoutput"],
         IPythonMagicType.HELP: ["get_ipython().run_line_magic('pinfo"],
         IPythonMagicType.LINE: ["get_ipython().run_line_magic", "get_ipython().magic"],
@@ -170,7 +170,10 @@ class MagicHandler(ABC):
             True if the source contains ipython magic
         """
         src_count = source.count("get_ipython()")
-        return INPUT_SPLITTER.transform_cell(source).count("get_ipython()") > src_count
+        get_ipython_count: int = INPUT_SPLITTER.transform_cell(source).count(
+            "get_ipython()"
+        )
+        return get_ipython_count > src_count
 
     @staticmethod
     def get_ipython_magic_type(ipython_magic: str) -> Optional[IPythonMagicType]:
@@ -188,6 +191,11 @@ class MagicHandler(ABC):
         -------
         Optional[IPythonMagicType]
             Type of the IPython magic
+
+        Raises
+        ------
+        RuntimeError
+            This shouldn't normally happen, it's just a defensive check.
         """
         python_code = INPUT_SPLITTER.transform_cell(ipython_magic)
         magic_type: Optional[IPythonMagicType] = None
@@ -195,6 +203,10 @@ class MagicHandler(ABC):
             if any(prefix in python_code for prefix in prefixes):
                 magic_type = magic
                 break
+        else:  # pragma: nocover
+            raise RuntimeError(
+                "Unreachable code reached - please report a bug at https://github.com/nbQA-dev/nbQA"
+            )
 
         return magic_type
 
